@@ -1266,5 +1266,8 @@ class DataLabelingServiceGrpcAsyncIOTransport(DataLabelingServiceTransport):
             )
         return self._stubs["list_evaluation_jobs"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("DataLabelingServiceGrpcAsyncIOTransport",)
